diff --git a/src/structures/schemas/structure.schema.ts b/src/structures/schemas/structure.schema.ts
index 8de6014257d72ece380cc9dec9526ad9f3ff1dd2..a4745ffb328a51351752218b39009360e845f029 100644
--- a/src/structures/schemas/structure.schema.ts
+++ b/src/structures/schemas/structure.schema.ts
@@ -5,7 +5,7 @@ import { Week } from './week.schema';
 
 export type StructureDocument = Structure & Document;
 
-@Schema({ timestamps: { createdAt: 'createdAt', updatedAt: 'updatedAt' } })
+@Schema({ timestamps: true })
 export class Structure {
   @Prop()
   numero: string;
diff --git a/src/structures/services/structures.service.ts b/src/structures/services/structures.service.ts
index 6b70fb759afb91ac0cdbf13aa65569eb43dfc2a1..e5e3573653514c88824fca95fd384e53d9cdf8cd 100644
--- a/src/structures/services/structures.service.ts
+++ b/src/structures/services/structures.service.ts
@@ -182,11 +182,10 @@ export class StructuresService {
     otherCategories: CategoriesOthers[]
   ): Promise<StructureDocument[]> {
     const structures = await this.structureModel.find({ deletedAt: { $exists: false } }).exec();
-
     // Update structures coord and address before sending them
     await Promise.all(
       structures.map((structure: StructureDocument) => {
         // If structre has no address, add it
         if (!structure.address || structure.coord.length <= 0) {
           return this.getStructurePosition(structure).then((postition: StructureDocument) => {
             this.structureModel
@@ -205,6 +204,14 @@ export class StructuresService {
         .select('-_id -accountVerified -otherDescription')
         .exec()
     ).map((structure) => {
+      // If structure has temp email, hide it
+      if (this.hasTempMail(structure)) {
+        structure.contactMail = null;
+      }
+      // Format date
+      structure.createdAt = new Date(structure.createdAt).toISOString();
+      structure.updatedAt = new Date(structure.updatedAt).toISOString();
+      // Add referentiel
       structure.proceduresAccompaniment = this.mapModules(
         structure.proceduresAccompaniment,
         accompagnementCategories.find((category) => category.id === 'proceduresAccompaniment').modules
@@ -586,4 +593,8 @@ export class StructuresService {
     });
     this.mailerService.send(emailsObject, jsonConfig.subject, html);
   }
+
+  private hasTempMail(structure: Structure): boolean {
+    return structure.contactMail === 'unknown@unknown.com';
+  }
 }
@@ -182,11 +182,10 @@ export class StructuresService {
     await Promise.all(
       structures.map((structure: StructureDocument) => {
-        // If structre has no address, add it
+        // If structure has no address, add it
         if (!structure.address || structure.coord.length <= 0) {
           return this.getStructurePosition(structure).then((postition: StructureDocument) => {